@@ -1,14 +1,14 @@
 package POEx::ProxySession::Client;
-our $VERSION = '0.092360';
-
+BEGIN {
+  $POEx::ProxySession::Client::VERSION = '1.102750';
+}
 
 #ABSTRACT: Proxies remote, published Sessions, or publishes, local Sessions for subscription
 
 use MooseX::Declare;
 
 
-class POEx::ProxySession::Client
-{
+class POEx::ProxySession::Client {
     with 'POEx::ProxySession::MessageSender';
     use POEx::ProxySession::Types(':all');
     use POEx::Types(':all');
@@ -16,7 +16,6 @@ class POEx::ProxySession::Client
     use MooseX::Types;
     use MooseX::Types::Moose(':all');
     use MooseX::Types::Structured('Optional','Dict','Tuple');
-    use MooseX::AttributeHelpers;
     use Moose::Util('does_role');
     use Storable('thaw', 'nfreeze');
     use Socket;
@@ -29,19 +28,19 @@ class POEx::ProxySession::Client
 
     has subscriptions =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => [ 'Hash' ],
         isa         => HashRef[Dict[ meta => class_type('Moose::Meta::Class'), wheel => WheelID ]],
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_subscriptions',
-        provides    => 
+        handles     => 
         {
-            get     => 'get_subscription',
-            set     => 'set_subscription',
-            delete  => 'delete_subscription',
-            count   => 'count_subscriptions',
-            keys    => 'all_subscription_names',
-            exists  => 'has_subscription',
+            get_subscription        => 'get',
+            set_subscription        => 'set',
+            delete_subscription     => 'delete',
+            count_subscriptions     => 'count',
+            all_subscription_names  => 'keys',
+            has_subscription        => 'exists',
         }
     );
 
@@ -49,7 +48,7 @@ class POEx::ProxySession::Client
 
     has publications =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => [ 'Hash' ],
         isa         => HashRef
         [
             Dict
@@ -62,21 +61,21 @@ class POEx::ProxySession::Client
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_publications',
-        provides    => 
+        handles     => 
         {
-            get     => 'get_publication',
-            set     => 'set_publication',
-            delete  => 'delete_publication',
-            count   => 'count_publications',
-            keys    => 'all_publication_names',
-            exists  => 'has_publication',
+            get_publication        => 'get',
+            set_publication        => 'set',
+            delete_publication     => 'delete',
+            count_publications     => 'count',
+            all_publication_names  => 'keys',
+            has_publication        => 'exists',
         }
     );
 
 
     has active_connections =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => [ 'Hash' ],
         isa         => HashRef
         [
             Dict
@@ -89,14 +88,14 @@ class POEx::ProxySession::Client
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_active_connections',
-        provides    => 
+        handles     => 
         {
-            get     => 'get_active_connection',
-            set     => 'set_active_connection',
-            delete  => 'delete_active_connection',
-            count   => 'count_active_connections',
-            keys    => 'all_active_connection_ids',
-            exists  => 'has_active_connection',
+            get_active_connection        => 'get',
+            set_active_connection        => 'set',
+            delete_active_connection     => 'delete',
+            count_active_connections     => 'count',
+            all_active_connection_ids    => 'keys',
+            has_active_connection        => 'exists',
         }
     );
 
@@ -125,8 +124,7 @@ class POEx::ProxySession::Client
     );
 
 
-    method handle_inbound_data(ProxyMessage $data, WheelID $id) is Event
-    {
+    method handle_inbound_data(ProxyMessage $data, WheelID $id) is Event {
         if($data->{type} eq 'result')
         {
             if($self->has_pending($data->{id}))
@@ -187,8 +185,8 @@ class POEx::ProxySession::Client
 
     with 'POEx::Role::TCPClient';
 
-    after _start(@args) is Event
-    {
+
+    after _start(@args) is Event {
         $self->filter(POE::Filter::Reference->new());
     }
 
@@ -200,8 +198,7 @@ class POEx::ProxySession::Client
         SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, 
         Str :$return_event,
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
         if(is_Session($return_session) or is_DoesSessionInstantiation($return_session))
         {
             $return_session = $return_session->ID;
@@ -220,8 +217,7 @@ class POEx::ProxySession::Client
     }
 
 
-    after handle_on_connect(GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
-    {
+    after handle_on_connect(GlobRef $socket, Str $address, Int $port, WheelID $id) is Event {
         if($self->has_connection_tag($id))
         {
             my $tag = $self->delete_connection_tag($id);
@@ -251,8 +247,7 @@ class POEx::ProxySession::Client
         }
     }
 
-    after handle_socket_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-    {
+    after handle_socket_error(Str $action, Int $code, Str $message, WheelID $id) is Event {
         $self->delete_wheel($id);
         my $connection = $self->delete_active_connection($id);
         
@@ -268,12 +263,11 @@ class POEx::ProxySession::Client
 
 
 
-    after handle_connect_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-    {
+    after handle_connect_error(Str $action, Int $code, Str $message, WheelID $id) is Event {
         $self->delete_socket_factory($id);
         my $tag = $self->delete_connection_tag($id);
 
-        if($self->has_connec_error_event)
+        if($self->has_connect_error_event)
         {
             $self->post
             (
@@ -292,8 +286,8 @@ class POEx::ProxySession::Client
         SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, 
         Str :$return_event,
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
+
         if(is_Session($return_session) or is_DoesSessionInstantiation($return_session))
         {
             $return_session = $return_session->ID;
@@ -325,8 +319,7 @@ class POEx::ProxySession::Client
         );
     }
 
-    method handle_on_subscribe(ProxyMessage $data, WheelID $id, HashRef $tag) is Event
-    {
+    method handle_on_subscribe(ProxyMessage $data, WheelID $id, HashRef $tag) is Event {
         if($data->{success})
         {
             Proxy->new
@@ -356,8 +349,7 @@ class POEx::ProxySession::Client
         }
     }
 
-    method handle_on_proxy(SessionAlias $session_name, Object $meta, WheelID $id) is Event
-    {
+    method handle_on_proxy(SessionAlias $session_name, Object $meta, WheelID $id) is Event {
         $self->set_subscription($session_name, { meta => $meta, wheel => $id});
     }
 
@@ -368,8 +360,8 @@ class POEx::ProxySession::Client
         SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, 
         Str :$return_event,
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
+
         die "Unknown session '$session_name'"
             if not $self->has_subscription($session_name);
         
@@ -429,8 +421,7 @@ class POEx::ProxySession::Client
         SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, 
         Str :$return_event,
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
         
         if(is_Session($return_session) or is_DoesSessionInstantiation($return_session))
         {
@@ -520,8 +511,7 @@ class POEx::ProxySession::Client
         );
     }
 
-    method handle_on_publish(ProxyMessage $data, WheelID $id, HashRef $tag) is Event
-    {
+    method handle_on_publish(ProxyMessage $data, WheelID $id, HashRef $tag) is Event {
         if($data->{success})
         {
             $self->set_publication
@@ -555,8 +545,8 @@ class POEx::ProxySession::Client
         SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, 
         Str :$return_event,
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
+
         if(is_Session($return_session) or is_DoesSessionInstantiation($return_session))
         {
             $return_session = $return_session->ID;
@@ -591,8 +581,7 @@ class POEx::ProxySession::Client
         );
     }
 
-    method handle_on_rescind(ProxyMessage $data, WheelID $id, HashRef $tag) is Event
-    {
+    method handle_on_rescind(ProxyMessage $data, WheelID $id, HashRef $tag) is Event {
         if($data->{success})
         {
             $self->delete_publication($tag->{session});
@@ -618,8 +607,8 @@ class POEx::ProxySession::Client
         SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, 
         Str :$return_event,
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
+
         if(is_Session($return_session) or is_DoesSessionInstantiation($return_session))
         {
             $return_session = $return_session->ID;
@@ -646,8 +635,8 @@ class POEx::ProxySession::Client
         );
     }
 
-    method handle_on_listing(ProxyMessage $data, WheelID $id, HashRef $tag) is Event
-    {
+    method handle_on_listing(ProxyMessage $data, WheelID $id, HashRef $tag) is Event {
+
         my %args = ( success => $data->{success}, payload => thaw($data->{payload}) );
         $self->post
         (
@@ -662,7 +651,6 @@ class POEx::ProxySession::Client
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -671,7 +659,7 @@ POEx::ProxySession::Client - Proxies remote, published Sessions, or publishes, l
 
 =head1 VERSION
 
-version 0.092360
+version 1.102750
 
 =head1 SYNOPSIS
 
@@ -681,10 +669,10 @@ version 0.092360
         with 'POEx::Role::SessionInstantiation';
         use aliased 'POEx::Role::Event';
         use aliased 'POEx::Role::ProxyEvent';
-
+        
         # The event we want to expose
         method yarg() {  } is ProxyEvent
-
+        
         after _start(@args) is Event
         {
             POEx::ProxySession::Client->new
@@ -729,7 +717,7 @@ version 0.092360
     {
         use aliased 'POEx::Role::Event';
         use aliased 'POEx::Role::ProxyEvent';
-
+        
         after _start(@args) is Event
         {
             POEx::ProxySession::Client->new
@@ -764,7 +752,7 @@ version 0.092360
                 return_event    => 'post_subscription',
             );
         }
-
+        
         method post_subscription(Bool :$success, Str :$session_name, Ref :$payload?) is Event
         {
             if($success)
@@ -774,8 +762,6 @@ version 0.092360
         }
     }
 
-
-
 =head1 DESCRIPTION
 
 POEx::ProxySession::Client enables remote sessions to interact with one another
@@ -783,27 +769,21 @@ via a system of subscription and publication. Client works via introspection on
 Moose::Meta::Classes to build local, persistent sessions that proxy posts back
 to the publisher with the attendant method signatures.
 
-=head1 CAVEATS
+=head1 PUBLIC_ATTRIBUTES
 
-It should be noted that the transport mechanism makes use of Storable. That
-means that all of the various end points in a spawling system need to use the
-same version of Storable to make sure things serialize/deserialize correctly.
-
-=head1 ATTRIBUTES
-
-=head2 subscriptions metaclass => MooseX::AttributeHelpers::Collection::Hash
+=head2 subscriptions 
 
 This attribute is used to store the various subscriptions made through the
 client. It has no accessors beyond what are defined in the provides mechanism.
 
-    provides    => 
+    handles     => 
     {
-        get     => 'get_subscription',
-        set     => 'set_subscription',
-        delete  => 'delete_subscription',
-        count   => 'count_subscriptions',
-        keys    => 'all_subscription_names',
-        exists  => 'has_subscription',
+        get_subscription        => 'get',
+        set_subscription        => 'set',
+        delete_subscription     => 'delete',
+        count_subscriptions     => 'count',
+        all_subscription_names  => 'keys',
+        has_subscription        => 'exists',
     }
 
 Each instance of a subscription is actually stored as a hash with the following
@@ -815,39 +795,33 @@ keys:
         wheel   => isa WheelID
     }
 
+=head2 active_connectios
 
+The clients active connects are stored in this attribute. The following methods
+are provided to access them:
 
-=head2 publications metaclass => MooseX::AttributeHelpers::Collection::Hash
-
-This attribute is used to store all publications made through the client. It 
-has no accessors beyond what are defined in the provides mechanism.
-
-    provides    => 
+    handles     => 
     {
-        get     => 'get_publication',
-        set     => 'set_publication',
-        delete  => 'delete_publication',
-        count   => 'count_publications',
-        keys    => 'all_publication_names',
-        exists  => 'has_publication',
+        get_active_connection        => 'get',
+        set_active_connection        => 'set',
+        delete_active_connection     => 'delete',
+        count_active_connections     => 'count',
+        all_active_connection_ids    => 'keys',
+        has_active_connection        => 'exists',
     }
 
-Each instance of a publication is stored as a hash with the following keys:
+Each connection is represented by a hashref with the following keys:
 
-    Publication =>
+    Connection =>
     {
-        methods         => isa HashRef,
-        wheel           => isa WheelID,
-        session_alias   => isa SessionAlias,
+        remote_address  => isa Str,
+        remote_port     => isa Int,
+        tag             => isa Optional[Ref],
     }
 
+=head2 unknown_message_event
 
-
-=head2 actice_connectios
-
-
-
-=head2 unknown_message_event is: 'rw', isa: Tuple[SessionID|SessionAlias, Str]
+    is: 'rw', isa: Tuple[SessionID|SessionAlias, Str]
 
 Set this attribute to receive unknown messages that were sent to the client. 
 This is handy for sending custom message types across the Server.
@@ -855,9 +829,9 @@ This is handy for sending custom message types across the Server.
 The event handler must have this signature:
 (ProxyMessage $data, WheelID $id)
 
+=head2 socket_error_event
 
-
-=head2 socket_error_event is: 'rw', isa: Tuple[SessionID|SessionAlias, Str]
+    is: 'rw', isa: Tuple[SessionID|SessionAlias, Str]
 
 When a socket error is received, the wheel is cleared, and the connection hash
 is deleted from the active connection structure. Set this attribute to be
@@ -866,9 +840,9 @@ notified when a socket error occurs.
 The event handler must have this signature:
 (Str :$remote_address, Int :$remote_port, Ref :$tag?)
 
+=head2 connect_error_event
 
-
-=head2 connect_error_event is: 'rw', isa: Tuple[SessionID|SessionAlias, Str]
+    is: 'rw', isa: Tuple[SessionID|SessionAlias, Str]
 
 When a connect error is received, the wheel is cleared, and the connection hash
 is deleted from the active connection structure. Set this attribute to be
@@ -877,56 +851,15 @@ notified when a socket error occurs.
 The event handler must have this signature:
 (Str :$remote_address, Int :$remote_port, Ref :$tag?)
 
+=head1 PUBLIC_METHODS
 
+=head2 subscribe
 
-=head1 METHODS
-
-=head2 handle_inbound_data(ProxyMessage $data, WheelID $id) is Event
-
-Our implementation of handle_inbound_data expects a ProxyMessage as data. Here 
-is where the handling and routing of messages lives. Only handles two types of
-ProxyMessage: result, and deliver. For more information on ProxyMessage types,
-see the POD in POEx::ProxySession::Types. If an unknown message type is
-encountered and unknown_message_event is set, it will be delivered to there.
-
-
-
-=head2 after _start(@args) is Event
-
-The _start method is advised to hardcode the filter to use as a 
-POE::Filter::Reference instance.
-
-
-
-=head2 around connect(Str :$remote_address,Int :$remote_port, SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,Str :$return_event,Ref :$tag?) is Event
-
-The connect method is advised to add additional parameters in the form of a
-return session and return event to use once the connection has been 
-established.
-
-The return event will need the following signature:
-(WheelID :$connection_id, Str :$remote_address, Int :$remote_port, Ref :tag?)
-
-
-
-=head2 after handle_on_connect(GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
-
-handle_on_connect is advised to find the specified return session and event
-and post the message with the paramters received from the socketfactory
-
-
-
-=head2 after handle_socket_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-
-
-
-
-=head2 after handle_connect_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-
-
-
-
-=head2 subscribe(WheelID :$connection_id, SessionAlias :$to_session, SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,Str :$return_event, Ref :$tag?) is Event
+    (WheelID :$connection_id,
+    SessionAlias :$to_session,
+    SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,
+    Str :$return_event,
+    Ref :$tag?) is Event
 
 subscribe sends a message out to the server, and the handler receives the 
 appropriate metadata and constructs a local, persistent session that proxies 
@@ -942,9 +875,12 @@ and if not $payload will be a scalar reference to a string explaining why.
 Otherwise, if subscription was successful, $payload will contain the original
 payload from the server containing the metadata.
 
+=head2 unsubscribe
 
-
-=head2 unsubscribe(SessionAlias :$session_name, SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, Str :$return_event, Ref :$tag) is Event
+    (SessionAlias :$session_name,
+    SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,
+    Str :$return_event,
+    Ref :$tag) is Event
 
 To unsubscribe from a proxied session, use this method. This will destroy the 
 session by removing its alias. Only pending events will keep the session alive.
@@ -956,10 +892,14 @@ the return event.
 The return event must have the following signature:
 (Bool :$success, SessionAlias :$session_alias, Ref :$tag?)
 
+=head2 publish
 
-
-
-=head2 publish(WheelID :$connection_id, SessionAlias :$session_alias, DoesSessionInstantiation :$session, SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, Str :$return_event, Ref :$tag?) is Event
+    (WheelID :$connection_id,
+    SessionAlias :$session_alias,
+    DoesSessionInstantiation :$session,
+    SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,
+    Str :$return_event,
+    Ref :$tag?) is Event
 
 This method will publish a particular session to the server, such that other 
 clients can then subscribe.
@@ -970,7 +910,7 @@ should happen. The session_alias argument is how the session should be
 addressed on the server. The alias will be used by subscribing clients.
 
 Currently, only sessions that are composed of POEx::Role::SessionInstantiation
-are supported and as such, a reference a session that does that role is 
+are supported and as such, a reference to a session that does that role is 
 required to allow the proper introspection on the subscriber end.
 
 To indicate which methods should be proxied, simply decorate them with the 
@@ -986,9 +926,12 @@ and if not $payload will be a scalar reference to a string explaining why.
 Otherwise, if publication was successful, $payload will contain the original
 payload from the server containing the metadata.
 
+=head2 rescind
 
-
-=head2 rescind(DoesSessionInstantiation :$session, SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, Str :$return_event, Ref :$tag?) is Event
+    (DoesSessionInstantiation :$session,
+    SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,
+    Str :$return_event,
+    Ref :$tag?) is Event
 
 To take back a publication, use this method and pass it the session reference.
 
@@ -999,9 +942,12 @@ Since rescinding can fail, $success will let you know if it did. And if it did,
 $payload will be a reference a string explaining why. Otherwise, payload will
 be undef.
 
+=head2 server_listing
 
-
-=head2 server_listing(WheelID :$connection_id, SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?, Str :$return_event, Ref :$tag?) is Event
+    (WheelID :$connection_id,
+    SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,
+    Str :$return_event,
+    Ref :$tag?) is Event
 
 server_listing will query a particular server for a list of all published 
 sessions that it knows about. It returns it as an array of session aliases
@@ -1010,22 +956,98 @@ suitable for subscription.
 The return event must have the following signature:
 (WheelID :$connection_id, Bool :$success, ArrayRef :$payload, Ref :$tag?)
 
+=head1 PROTECTED_METHODS
 
+=head2 handle_inbound_data
+
+    (ProxyMessage $data, WheelID $id) is Event
+
+Our implementation of handle_inbound_data expects a ProxyMessage as data. Here 
+is where the handling and routing of messages lives. Only handles two types of
+ProxyMessage: result, and deliver. For more information on ProxyMessage types,
+see the POD in POEx::ProxySession::Types. If an unknown message type is
+encountered and unknown_message_event is set, it will be delivered to there.
+
+=head2 around connect
+
+    (Str :$remote_address,
+    Int :$remote_port,
+    SessionAlias|SessionID|Session|DoesSessionInstantiation :$return_session?,
+    Str :$return_event,
+    Ref :$tag?) is Event
+
+The connect method is advised to add additional parameters in the form of a
+return session and return event to use once the connection has been 
+established.
+
+The return event will need the following signature:
+(WheelID :$connection_id, Str :$remote_address, Int :$remote_port, Ref :tag?)
+
+=head2 after handle_on_connect
+
+    (GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
+
+handle_on_connect is advised to find the specified return session and event
+and post the message with the paramters received from the socketfactory
+
+=head2 after handle_socket_error
+
+    (Str $action, Int $code, Str $message, WheelID $id) is Event
+
+handle_socket_error is advised to clean up the active connection if an error
+has occurred. The socket_error_event is delivered then with the connection
+information if there is such an event.
+
+=head2 after handle_connect_error
+
+    (Str $action, Int $code, Str $message, WheelID $id) is Event
+
+handle_connect_error is advised to clean up resources such as the socket
+factory and the connection tag if there was a error connecting. The error along
+with the tag information is delivered to the connect_error_event if it has been
+defined.
+
+=head1 PRIVATE_METHODS
+
+=head2 after _start
+
+    (@args) is Event
+
+The _start method is advised to hardcode the filter to use as a 
+POE::Filter::Reference instance.
+
+=attrbute_public publications
+
+This attribute is used to store all publications made through the client. It 
+has no accessors beyond what are defined in the provides mechanism.
+
+Each instance of a publication is stored as a hash with the following keys:
+
+    Publication =>
+    {
+        methods         => isa HashRef,
+        wheel           => isa WheelID,
+        session_alias   => isa SessionAlias,
+    }
+
+=head1 CAVEATS
+
+It should be noted that the transport mechanism makes use of Storable. That
+means that all of the various end points in a spawling system need to use the
+same version of Storable to make sure things serialize/deserialize correctly.
 
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Nicholas Perez.
+This software is copyright (c) 2010 by Nicholas Perez.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
-
-=cut 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
 
 __END__
