@@ -1,15 +1,14 @@
 package POEx::ProxySession::MessageSender;
-our $VERSION = '0.092360';
-
+BEGIN {
+  $POEx::ProxySession::MessageSender::VERSION = '1.102750';
+}
 
 #ABSTRACT: ProxySession utility Role for sending message
 
 use MooseX::Declare;
 
-role POEx::ProxySession::MessageSender
-{
+role POEx::ProxySession::MessageSender {
     use MooseX::Types::Moose(':all');
-    use MooseX::AttributeHelpers;
     use POEx::Types(':all');
     use POEx::ProxySession::Types(':all');
     use Storable('nfreeze');
@@ -19,52 +18,51 @@ role POEx::ProxySession::MessageSender
 
     has pending =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => ['Hash'],
         isa         => HashRef[HashRef],
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_pending',
-        provides    => 
+        handles    => 
         {
-            get     => 'get_pending',
-            set     => 'set_pending',
-            delete  => 'delete_pending',
-            count   => 'count_pending',
-            exists  => 'has_pending',
-            values  => 'all_pending',
+            get_pending        => 'get',
+            set_pending        => 'set',
+            delete_pending     => 'delete',
+            count_pending      => 'count',
+            has_pending        => 'exists',
+            all_pending        => 'values',
         }
 
     );
 
+
     has queue =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => [ 'Hash' ],
         isa         => HashRef[ArrayRef],
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_queue',
-        provides    =>
+        handles     =>
         {
-            get     => 'get_queued',
-            set     => 'set_queued',
-            delete  => 'delete_queued',
-            count   => 'count_queued',
-            exists  => 'has_queued',
-            values  => 'all_queued',
-            keys    => 'all_sessions_queued',
+            get_queued          => 'get',
+            set_queued          => 'set',
+            delete_queued       => 'delete',
+            count_queued        => 'count',
+            has_queued          => 'exists',
+            all_queued          => 'values',
+            all_sessions_queued => 'keys',
         }
     );
 
     
     my $id = 0;
-    method next_message_id() returns (Int)
-    {
+    method next_message_id() returns (Int) {
         return $id++;
     }
 
 
-    method send_result(Bool :$success, ProxyMessage :$original, Ref :$payload?, WheelID :$wheel_id) is Event
-    {
+    method send_result(Bool :$success, ProxyMessage :$original, Ref :$payload?, WheelID :$wheel_id) is Event {
         my $msg = 
         {
             id      => $original->{id},
@@ -93,8 +91,7 @@ role POEx::ProxySession::MessageSender
     }
 
 
-    method send_message(Str :$type, Ref :$payload, WheelID :$wheel_id) is Event
-    {
+    method send_message(Str :$type, Ref :$payload, WheelID :$wheel_id) is Event {
         my $msg = { type => $type, id => $self->next_message_id(), payload => nfreeze($payload) };
         
         if($self->has_wheel($wheel_id))
@@ -123,8 +120,8 @@ role POEx::ProxySession::MessageSender
         SessionID :$return_session, 
         Str :$return_event, 
         Ref :$tag?
-    ) is Event
-    {
+    ) is Event {
+
         $message->{id} = $self->next_message_id();
         $self->set_pending($message->{id}, { tag => $tag, return_session => $return_session, return_event => $return_event });
         
@@ -149,7 +146,6 @@ role POEx::ProxySession::MessageSender
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -158,74 +154,79 @@ POEx::ProxySession::MessageSender - ProxySession utility Role for sending messag
 
 =head1 VERSION
 
-version 0.092360
+version 1.102750
 
 =head1 DESCRIPTION
 
 POEx::ProxySession::MessageSender is a utility role that both Client and Server
 consume to provide common semantics to sending messages. 
 
-=head1 ATTRIBUTES
+=head1 PROTECTED_ATTRIBUTES
 
-=head2 pending metaclass => MooseX::AttributeHelpers::Collection::Hash
+=head2 pending
 
 pending stores context related data of messages where a result is expected.
 
-It has no accessors beyond those provided by AttributeHelpers:
+Access this attribute via the following methods:
 
-    provides    => 
+    handles    => 
     {
-        get     => 'get_pending',
-        set     => 'set_pending',
-        delete  => 'delete_pending',
-        count   => 'count_pending',
-        exists  => 'has_pending',
+        get_pending        => 'get',
+        set_pending        => 'set',
+        delete_pending     => 'delete',
+        count_pending      => 'count',
+        has_pending        => 'exists',
+        all_pending        => 'values',
     }
 
+=head2 queue
 
+queue holds all of the queues for the various connected wheels. If a message is
+unable to be immediately delivered to a wheel, it will go into that wheel's
+queue.
 
-=head1 METHODS
+Each queue is merely an arrayref of messages to be delivered.
 
-=head2 next_message_id() returns (Int)
+=head1 PROTECTED_METHODS
+
+=head2 next_message_id
+
+    returns (Int)
 
 This method returns the next message id to be used.
 
+=head2 send_result
 
-
-=head2 send_result(Bool :$success, ProxyMessage :$original, Ref :$payload?, WheelID :$wheel_id) is Event
+    (Bool :$success, ProxyMessage :$original, Ref :$payload?, WheelID :$wheel_id) is Event
 
 This is a convenience method for sending result messages to the original sender.
 
+=head2 send_message
 
-
-=head2 send_message(Str :$type, Ref :$payload, WheelID :$wheel_id) is Event
+    (Str :$type, Ref :$payload, WheelID :$wheel_id) is Event
 
 This method creates a message with the provided payload and delivers it via the
 connection that wheel_id references.
 
+=head2 return_to_sender
 
-
-=head2 return_to_sender(ProxyMessage :$message,WheelID :$wheel_id, SessionID :$return_session,Str :$return_event,Ref :$tag?) is Event
+    (ProxyMessage :$message,WheelID :$wheel_id, SessionID :$return_session,Str :$return_event,Ref :$tag?) is Event
 
 This method sends a message, and also stores context information related to the
 message including where to send the result.
 
-
-
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Nicholas Perez.
+This software is copyright (c) 2010 by Nicholas Perez.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
-
-=cut 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
 
 __END__
