@@ -1,19 +1,18 @@
 package POEx::ProxySession::Server;
-our $VERSION = '0.092360';
-
+BEGIN {
+  $POEx::ProxySession::Server::VERSION = '1.102750';
+}
 
 #ABSTRACT: Hosts published sessions and routes proxy message
 
 use MooseX::Declare;
 
 
-class POEx::ProxySession::Server
-{
+class POEx::ProxySession::Server {
     with 'POEx::ProxySession::MessageSender';
     use POEx::ProxySession::Types(':all');
     use POEx::Types(':all');
     use MooseX::Types::Moose(':all');
-    use MooseX::AttributeHelpers;
     use Storable('thaw', 'nfreeze');
     use POE::Filter::Reference;
     use aliased 'POEx::Role::Event';
@@ -21,44 +20,44 @@ class POEx::ProxySession::Server
 
     has sessions =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => [ 'Hash' ],
         isa         => HashRef,
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_sessions',
-        provides    => 
+        handles     => 
         {
-            get     => 'get_session',
-            set     => 'set_session',
-            delete  => 'delete_session',
-            count   => 'count_sessions',
-            keys    => 'all_session_names',
-            exists  => 'has_session',
+            get_session        => 'get',
+            set_session        => 'set',
+            delete_session     => 'delete',
+            count_sessions     => 'count',
+            all_session_names  => 'keys',
+            has_session        => 'exists',
         }
     );
 
+
     has delivered_store =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
+        traits      => [ 'Hash' ],
         isa         => HashRef,
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_delivereds',
-        provides    => 
+        handles     => 
         {
-            get     => 'get_delivered',
-            set     => 'set_delivered',
-            delete  => 'delete_delivered',
-            count   => 'count_delivereds',
-            keys    => 'all_delivered_keys',
-            values  => 'all_delivered_values',
-            exists  => 'has_delivered',
+            get_delivered        => 'get',
+            set_delivered        => 'set',
+            delete_delivered     => 'delete',
+            count_delivereds     => 'count',
+            all_delivered_keys   => 'keys',
+            all_delivered_values => 'values',
+            has_delivered        => 'exists',
         }
     );
 
 
-    method handle_inbound_data(ProxyMessage $data, WheelID $id) is Event
-    {
+    method handle_inbound_data(ProxyMessage $data, WheelID $id) is Event {
         if ($data->{type} eq 'publish')
         {
             $self->yield('publish_session', $data, $id);
@@ -100,14 +99,12 @@ class POEx::ProxySession::Server
     with 'POEx::Role::TCPServer';
 
 
-    after _start(@args) is Event
-    {
+    after _start(@args) is Event {
         $self->filter(POE::Filter::Reference->new());
     }
 
 
-    method rescind_session(ProxyMessage $data, WheelID $id) is Event
-    {
+    method rescind_session(ProxyMessage $data, WheelID $id) is Event {
         my $payload = thaw($data->{payload});
         my $session = $payload->{session_alias};
 
@@ -148,8 +145,7 @@ class POEx::ProxySession::Server
     }
 
 
-    method publish_session(ProxyMessage $data, WheelID $id) is Event
-    {
+    method publish_session(ProxyMessage $data, WheelID $id) is Event {
         my $payload = thaw($data->{payload});
 
         my $alias = $payload->{session_alias};
@@ -204,8 +200,8 @@ class POEx::ProxySession::Server
         }
     }
 
-    method subscribe_session(ProxyMessage $data, WheelID $id) is Event
-    {
+
+    method subscribe_session(ProxyMessage $data, WheelID $id) is Event {
         my $session_name = $data->{to};
         if(!$self->has_session($session_name))
         {
@@ -233,8 +229,7 @@ class POEx::ProxySession::Server
     }
 
 
-    method deliver_message(ProxyMessage $data, WheelID $id) is Event
-    {
+    method deliver_message(ProxyMessage $data, WheelID $id) is Event {
         my $session = $data->{to};
         
         if(!$self->has_session($session))
@@ -258,8 +253,7 @@ class POEx::ProxySession::Server
         $self->get_wheel($wheel_id)->put($data);
     }
 
-    method handle_delivered(ProxyMessage $data, WheelID $id) is Event
-    {
+    method handle_delivered(ProxyMessage $data, WheelID $id) is Event {
         if($self->has_pending($data->{id}))
         {
             my $pending = $self->delete_pending($data->{id});
@@ -277,8 +271,7 @@ class POEx::ProxySession::Server
     }
 
 
-    method get_listing(ProxyMessage $data, WheelID $id) is Event
-    {
+    method get_listing(ProxyMessage $data, WheelID $id) is Event {
         $self->yield
         (
             'send_result', 
@@ -293,7 +286,6 @@ class POEx::ProxySession::Server
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -302,7 +294,7 @@ POEx::ProxySession::Server - Hosts published sessions and routes proxy message
 
 =head1 VERSION
 
-version 0.092360
+version 1.102750
 
 =head1 SYNOPSIS
 
@@ -322,122 +314,127 @@ class Flarg
     }
 }
 
-
-
-
 =head1 DESCRIPTION
 
 POEx::ProxySession::Server is a lightweight network server that handles 
 storage and listing of published sessions, and routing of proxied messages
 between connected clients.
 
-=head1 ATTRIBUTES
+=head1 PROTECTED_ATTRIBUTES
 
-=head2 sessions metaclass => MooseX::AttributeHelpers::Collection::Hash
+=head2 sessions
 
-This attribute is used to store the published sessions. It has no accessors
-beyond what is provided by AttributeHelpers:
+This attribute is used to store the published sessions.
 
-    provides    => 
-    {
-        get     => 'get_session',
-        set     => 'set_session',
-        delete  => 'delete_session',
-        count   => 'count_sessions',
-        keys    => 'all_session_names',
-        exists  => 'has_session',
-    }
+Access these sessions through the following methods:
 
 The stored structure looks like the following:
 
     Session =>
     {
         name    => isa SessionAlias,
-        methods => HashRef,
+        methods => isa HashRef,
         id      => isa WheelID,
     }
 
+=head2 delivered_store
 
+delivered_store holds the wheel ids that are awaiting a response from some
+other client. 
 
-=head1 METHODS
+Access to these ids is provided through the following methods:
 
-=head2 handle_inbound_data(ProxyMessage $data, WheelID $id) is Event
+    handles     => 
+    {
+        get_delivered        => 'get',
+        set_delivered        => 'set',
+        delete_delivered     => 'delete',
+        count_delivereds     => 'count',
+        all_delivered_keys   => 'keys',
+        all_delivered_values => 'values',
+        has_delivered        => 'exists',
+    }
+
+=head1 PROTECTED_METHODS
+
+=head2 handle_inbound_data
+
+    (ProxyMessage $data, WheelID $id) is Event
 
 Our implementation of handle_inbound_data expects a ProxyMessage as data. Here 
 is where the handling and routing of messages lives. The following types of 
 messages are handled here: publish, rescind, listing, subscribe, deliver, and
 result. 
 
+=head2 rescind_session
 
-
-=head2 after _start(@args) is Event
-
-The _start method is advised to hardcode the filter to use as a 
-POE::Filter::Reference instance.
-
-
-
-=head2 rescind_session(ProxyMessage $data, WheelID $id) is Event
+    (ProxyMessage $data, WheelID $id) is Event
 
 This handles rescinding of a published session. No payload on success.
 
+=head2 publish_session
 
-
-=head2 publish_session(ProxyMessage $data, WheelID $id) is Event
+    (ProxyMessage $data, WheelID $id) is Event
 
 This method handles session publication. Payload on success is the session 
 alias
 
+=head2 subscribe_session
 
-
-=head2 subscribe_session(ProxyMessage $data, WheelID $id) is Event
+    (ProxyMessage $data, WheelID $id) is Event
 
 This method handles subscription requests. Payload on success is a hashref:
 
+    Payload =>
     {
         session => isa SessionAlias,
         methods => HashRef,
     }
 
+=head2 deliver_message
 
-
-=head2 deliver_message(ProxyMessage $data, WheelID $id) is Event
+    (ProxyMessage $data, WheelID $id) is Event
 
 This method does message delivery by doing a lookup of the alias to the real
 session name, and rewriting the message header to point to that session, then
 sends it on to that session's connection. Sets a delivered message.
 
+=head2 handle_delivered
 
-
-=head2 handle_delivered(ProxyMessage $data, WheelID $id) is Event
+    (ProxyMessage $data, WheelID $id) is Event
 
 This method handles result messages from delivered messages. All messages that 
 go through the system are expected to return a result message indicating 
 success or failure.
 
+=head2 get_listing
 
-
-=head2 get_listing(ProxyMessage $data, WheelID $id) is Event
+    (ProxyMessage $data, WheelID $id) is Event
 
 This method handles listing requests from clients. Should always succeed.
 Payload is an ArrayRef[SessionAlias].
 
+=head1 PRIVATE_METHODS
 
+=head2 after _start
+
+    (@args) is Event
+
+The _start method is advised to hardcode the filter to use as a 
+POE::Filter::Reference instance.
 
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Nicholas Perez.
+This software is copyright (c) 2010 by Nicholas Perez.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
-
-=cut 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
 
 __END__
